@@ -102,6 +102,11 @@ pub fn save(env: &Environment) {
     Environment::save(env)
 }
 
+/// Prints a bold orange message
+pub fn print_message(msg: &str) {
+    println!("{}", msg.bold().color(ORANGE))
+}
+
 pub const ORANGE: colored::Color = colored::Color::TrueColor {
     r: 255,
     g: 127,
@@ -152,15 +157,17 @@ pub static CRATES: Lazy<std::collections::HashSet<String>> = Lazy::new(|| {
                 std::process::exit(1);
             }
 
-            let git = std::process::Command::new("git").args([&format!("--work-tree={}", config),"checkout", "master", "--", "crates"]).status();
+            std::env::set_current_dir(config).unwrap();
+
+            let git = std::process::Command::new("git").args(["checkout", "master", "--", "crates"]).status();
             if let Err(e) = git {
                 println!("{}: {}", "error: ".red(), e.to_string());
                 std::process::exit(1);
             }
 
             println!("{}", "\nDownload completed, compiling Crates: ".bold().color(ORANGE));
-            for cr in include_str!("essential_crates.txt").split_whitespace() {
-                println!("Compiling {}", cr);
+            for cr in include_str!("core_crates.txt").split_whitespace() {
+                println!("\n{}", cr.bold());
                 std::process::Command::new("cargo")
                     .arg("build")
                     .arg("--release")
